@@ -229,22 +229,18 @@ class Book:
                     ]
 
     @classmethod
-    def get(self, book_id):
+    def get(cls, book_id):
         client = Requestor()
         status, book = client.request("detail", [("book_id", book_id)])
         book = book[0]
 
         if book["status"] != "n":
-            status, preview_data = client.request(
-                "preview", [("book_id", book_id)]
-            )
-            if status == "OK":
-                book["previews"] = preview_data.get("data", {})
+            book["previews"] = cls.preview(book_id, ignore_exceptions=True)
 
-        return Book(book)
+        return cls(book)
 
     @classmethod
-    def available(self, book_id, user_id):
+    def available(cls, book_id, user_id):
         client = Requestor()
         status, response = client.request(
             "available", [("book_id", book_id), ("user_id", user_id)]
@@ -252,6 +248,22 @@ class Book:
 
         return True if status == "HAVEYET" else False
 
+    @classmethod
+    def preview(cls, book_id, ignore_exceptions=False):
+        client = Requestor()
+        try:
+            status, response = client.request(
+                "preview", [("book_id", book_id)]
+            )
+        except dibuk.error.APIError as e:
+            if ignore_exceptions:
+                status = "OK"
+                response = {}
+            else:
+                raise e
+
+        return response.get("data", {}) if status == "OK" else {}
+
 
 class Order:
     @classmethod
@@ -379,12 +391,7 @@ class Catalogue:
             book_id = int(book["id"])
 
             if include_previews is True and book["status"] != "n":
-                status, preview_data = client.request(
-                    "preview", [("book_id", book_id)]
-                )
-
-                if status == "OK":
-                    book["previews"] = preview_data.get("data", {})
+                book["previews"] = Book.preview(book_id, ignore_exceptions=True)
 
             books[book_id] = Book(book)
 
